@@ -66,14 +66,14 @@ NULL
 #'                                             .analytes = panel_info$analytes,
 #'                                             .method_args = args_ident_analyte)
 #'
-#' annot_events %>% facs_plot(.beads = "Bead group")
+#' annot_events |> facs_plot(.beads = "Bead group")
 #'
-#' annot_events %>%
-#'   filter(`Bead group` == "A") %>%
+#' annot_events |>
+#'   filter(`Bead group` == "A") |>
 #'   facs_plot(.x = "FL2-H", .y = "FL6-H", .beads = "Analyte ID")
 #'
-#' annot_events %>%
-#'   filter(`Bead group` == "B") %>%
+#' annot_events |>
+#'   filter(`Bead group` == "B") |>
 #'   facs_plot(.x = "FL2-H", .y = "FL6-H", .beads = "Analyte ID")
 #' }
 identify_legendplex_analyte <- function(df, .analytes, .method_args, .data = NULL){
@@ -88,7 +88,7 @@ identify_legendplex_analyte <- function(df, .analytes, .method_args, .data = NUL
   # Do bead identification
   df <- ident_bead_pop(.analytes = names(.analytes), .call_args = .method_args[[1]], df = df)
 
-  # To be able to subset on the beads A abd B, we need to know the name of the
+  # To be able to subset on the beads A and B, we need to know the name of the
   # column with identification of the two bead populations, but it is not
   # guaranteed to exist in the .method_args. If we don't find it, we set it to
   # the default
@@ -99,7 +99,7 @@ identify_legendplex_analyte <- function(df, .analytes, .method_args, .data = NUL
   }
 
   # ## Identify analytes ##
-  .analyte_gr12 <- .analytes %>%
+  .analyte_gr12 <- .analytes |>
     purrr::map2_df(.y = names(.analytes), .f = ident_bead_pop,
                    .column_name =.ab_col_name,
                    .call_args = .method_args[[length(.method_args)]],
@@ -114,8 +114,14 @@ identify_legendplex_analyte <- function(df, .analytes, .method_args, .data = NUL
     .id_col_name <- "analyte"
   }
 
-  df %>% dplyr::filter(is.na(!!rlang::sym(.ab_col_name))) %>%
-    dplyr::mutate(!!.id_col_name := as.character(NA)) %>%
+  df |>
+    dplyr::filter(
+      dplyr::if_all(
+        dplyr::all_of(.ab_col_name),
+        .fns = is.na
+      )
+    ) |>
+    dplyr::mutate({{.id_col_name}} := as.character(NA)) |>
     dplyr::bind_rows(.analyte_gr12)
 }
 
@@ -135,7 +141,7 @@ identify_legendplex_analyte <- function(df, .analytes, .method_args, .data = NUL
 #'
 #' df <- simplex[["cba"]]
 #'
-#' analytes <- vector("list", 30) %>% setNames(as.character(c(1:30)))
+#' analytes <- vector("list", 30) |> setNames(as.character(c(1:30)))
 #'
 #' args_ident_analyte <- list(.parameter = c("APC", "APC-Cy7"),
 #'                            .column_name = "Analyte ID",
@@ -145,9 +151,9 @@ identify_legendplex_analyte <- function(df, .analytes, .method_args, .data = NUL
 #'                      .analytes = analytes,
 #'                      .method_args = args_ident_analyte)
 #'
-#' annot_events %>% facs_plot(.x = "FSC", .y = "SSC")
+#' annot_events |> facs_plot(.x = "FSC", .y = "SSC")
 #'
-#' annot_events %>%
+#' annot_events |>
 #'   facs_plot(.x = "APC", .y = "APC-Cy7", .beads = "Analyte ID")
 #'
 #' annot_events <- identify_cba_analyte(df = df,
@@ -156,11 +162,11 @@ identify_legendplex_analyte <- function(df, .analytes, .method_args, .data = NUL
 #'                      .trim_fs = 0.1,
 #'                      .parameter_fs = c("FSC", "SSC"))
 #'
-#' annot_events %>% facs_plot(.x = "FSC", .y = "SSC", .beads = "Bead events")
+#' annot_events |> facs_plot(.x = "FSC", .y = "SSC", .beads = "Bead events")
 #'
 #' # Looks strange because some true beads events have randomly been placed far
 #' # from the center in the forward-side scatter when the data was created
-#' annot_events %>%
+#' annot_events |>
 #'   facs_plot(.x = "APC", .y = "APC-Cy7", .beads = "Analyte ID")
 #' }
 identify_cba_analyte <- function(df, .analytes, .method_args, .trim_fs = NULL, .parameter_fs = NULL, .data = NULL){
@@ -186,7 +192,7 @@ identify_cba_analyte <- function(df, .analytes, .method_args, .trim_fs = NULL, .
 #' data(simplex)
 #'
 #' df <- simplex[["mplex"]]
-#' analytes <- vector("list", 10) %>% setNames(as.character(c(1:10)))
+#' analytes <- vector("list", 10) |> setNames(as.character(c(1:10)))
 #'
 #' args_ident_analyte <- list(.parameter = c("FITC", "PE"),
 #'                            .column_name = "Analyte ID",
@@ -197,9 +203,9 @@ identify_cba_analyte <- function(df, .analytes, .method_args, .trim_fs = NULL, .
 #'                                      .analytes = analytes,
 #'                                      .method_args = args_ident_analyte)
 #'
-#' annot_events %>% facs_plot(.x = "FSC", .y = "SSC")
+#' annot_events |> facs_plot(.x = "FSC", .y = "SSC")
 #'
-#' annot_events %>%
+#' annot_events |>
 #'   facs_plot(.x = "FITC", .y = "PE", .beads = "Analyte ID")
 #'
 #' annot_events <- identify_macsplex_analyte(df = df,
@@ -208,10 +214,10 @@ identify_cba_analyte <- function(df, .analytes, .method_args, .trim_fs = NULL, .
 #'                                      .trim_fs = 0.1,
 #'                                      .parameter_fs = c("FSC", "SSC"))
 #'
-#' annot_events %>% facs_plot(.x = "FSC", .y = "SSC", .beads = "Bead events")
+#' annot_events |> facs_plot(.x = "FSC", .y = "SSC", .beads = "Bead events")
 #' # Looks strange because some true beads events have randomly been placed far
 #' # from the center in the forward-side scatter when the data was created
-#' annot_events %>%
+#' annot_events |>
 #'   facs_plot(.x = "FITC", .y = "PE", .beads = "Analyte ID")
 #' }
 identify_macsplex_analyte <- function(df, .analytes, .method_args, .trim_fs = NULL, .parameter_fs = NULL, .data = NULL){
@@ -245,18 +251,27 @@ identify_cba_macsplex_analyte <- function(df, .analytes, .method_args, .trim_fs
   df[[.fs_col_name]] <- "1"
 
   if(!is.null(.trim_fs)){
-    df <- df %>%
+    df <- df |>
       trim_population(.parameter = .parameter_fs, .column_name = .fs_col_name, .trim = .trim_fs)
   }
 
   # Extract non-accepted events
-  .na_events  <- df %>%
-    dplyr::filter(is.na(!!rlang::sym(.fs_col_name)))
-
+  .na_events  <- df |>
+    dplyr::filter(
+      dplyr::if_all(
+        dplyr::all_of(.fs_col_name),
+        .fns = is.na
+      )
+    )
 
   # Get just real events
-  df <- df %>%
-    dplyr::filter(!is.na(!!rlang::sym(.fs_col_name)))
+  df <- df |>
+    dplyr::filter(
+      dplyr::if_all(
+        dplyr::all_of(.fs_col_name),
+        .fns = ~!is.na(.)
+      )
+    )
 
   # Do bead identification
   df <- ident_bead_pop(.analytes = names(.analytes),.call_args = .method_args, df = df)
@@ -272,7 +287,7 @@ identify_cba_macsplex_analyte <- function(df, .analytes, .method_args, .trim_fs
   if(nrow(.na_events) > 0){
     .na_events[[.analyte_col_name]] <- NA
 
-    df <- df %>%
+    df <- df |>
       dplyr::bind_rows(.na_events)
   }
 
@@ -283,6 +298,7 @@ identify_cba_macsplex_analyte <- function(df, .analytes, .method_args, .trim_fs
   df
 }
 
+
 #' Identify analyte
 #'
 #' @inheritParams cluster_events
@@ -315,35 +331,34 @@ identify_cba_macsplex_analyte <- function(df, .analytes, .method_args, .trim_fs
 #' @examples
 #' \dontrun{
 #' library(beadplexr)
-#' library(magrittr)
 #' library(ggplot2)
 #'
 #' data("lplex")
 #'
 #' df <- lplex[[1]]
-#' df %>%
+#' df |>
 #'   identify_analyte(.parameter = c("FSC-A", "SSC-A"),
 #'                       .analyte_id = c("A", "B"),
 #'                       .column_name = "analyte",
-#'                       .method = "clara", .trim = 0.02) %>%
+#'                       .method = "clara", .trim = 0.02) |>
 #'   ggplot() +
 #'   aes(x = `FSC-A`, y = `SSC-A`, colour = analyte) +
 #'   geom_point()
 #'
-#' f
+#' df |>
 #'   identify_analyte(.parameter = c("FSC-A", "SSC-A"),
 #'                       .analyte_id = c("A", "B"),
 #'                       .column_name = "analyte",
-#'                       .method = "clara", .desc = TRUE) %>%
+#'                       .method = "clara", .desc = TRUE) |>
 #'   ggplot() +
 #'   aes(x = `FSC-A`, y = `SSC-A`, colour = analyte) +
 #'   geom_point()
 #'
-#' df %>%
+#' df |>
 #'   identify_analyte(.parameter = c("FSC-A", "SSC-A"),
 #'                       .analyte_id = c("A", "B"),
 #'                       .column_name = "analyte",
-#'                       .method = "dbscan") %>%
+#'                       .method = "dbscan") |>
 #'   ggplot() +
 #'   aes(x = `FSC-A`, y = `SSC-A`, colour = analyte) +
 #'   geom_point()
@@ -382,19 +397,19 @@ identify_analyte <-  function(df,
   )
 
   .num_clust_found <- .clust_res[[.cluster_column_name]]
-  .num_clust_found <- .num_clust_found[!is.na(.num_clust_found)] %>% unique %>% length
+  .num_clust_found <- .num_clust_found[!is.na(.num_clust_found)] |> unique() |> length()
 
   if(.num_clust_found != length(.analyte_id)){
     warning("The number of identified and expected clusters did not match. Setting everything to NA")
 
-    .clust_res <- .clust_res %>%
-      dplyr::select(-dplyr::one_of(.cluster_column_name)) %>%
+    .clust_res <- .clust_res |>
+      dplyr::select(-dplyr::all_of(.cluster_column_name)) |>
       dplyr::mutate(!!.column_name := as.character(NA))
 
     return(.clust_res)
   }
 
-  .clust_res %>% assign_analyte_id(.parameter = .parameter,
+  .clust_res |> assign_analyte_id(.parameter = .parameter,
                                       .analyte_id = .analyte_id,
                                       .column_name = .column_name,
                                       .cluster_column_name = .cluster_column_name,
@@ -424,28 +439,27 @@ identify_analyte <-  function(df,
 #' @examples
 #' \dontrun{
 #' library(beadplexr)
-#' library(magrittr)
 #' library(ggplot2)
 #'
 #' data("lplex")
 #'
-#' df <- lplex[[1]] %>%
+#' df <- lplex[[1]] |>
 #'   bp_clara(.parameter = c("FSC-A", "SSC-A"), .column_name = "analyte", .k = 2)
 #'
-#' df %>%
+#' df |>
 #'   beadplexr:::assign_analyte_id(.parameter = c("FSC-A", "SSC-A"),
 #'                                    .analyte_id = c("A", "B"),
 #'                                    .column_name = "pop name",
-#'                                    .cluster_column_name = "analyte") %>%
+#'                                    .cluster_column_name = "analyte") |>
 #'   ggplot() +
 #'   aes(x = `FSC-A`, y = `SSC-A`, colour = `pop name`) +
 #'   geom_point()
 #'
-#' df %>%
+#' df |>
 #'   beadplexr:::assign_analyte_id(.parameter = c("FSC-A", "SSC-A"),
 #'                                    .analyte_id = c("A", "B"),
 #'                                    .column_name = "pop name",
-#'                                    .cluster_column_name = "analyte", .desc = TRUE) %>%
+#'                                    .cluster_column_name = "analyte", .desc = TRUE) |>
 #'   ggplot() +
 #'   aes(x = `FSC-A`, y = `SSC-A`, colour = `pop name`) +
 #'   geom_point()
@@ -474,28 +488,37 @@ assign_analyte_id <- function(df,
   }
 
   if(.column_name %in% col_names_present){
-    df <- df %>%
-      dplyr::select(-dplyr::one_of(.column_name))
+    df <- df |>
+      dplyr::select(-dplyr::all_of(.column_name))
   }
 
-  clust_order <- df %>%
-    dplyr::filter(!is.na(!!rlang::sym(.cluster_column_name))) %>%
-    dplyr::group_by(!!rlang::sym(.cluster_column_name)) %>%
-    dplyr::summarise_at(dplyr::vars(dplyr::one_of(.parameter)), mean) %>%
-    dplyr::arrange(!!!rlang::syms(.parameter)) %>%
-    {if(.desc){
-      .[nrow(.):1, ]
-    }else{
-      .
-    }} %>%
-    dplyr::mutate(!!.column_name := .analyte_id)
+  clust_order <-
+    df |>
+      dplyr::filter(
+        dplyr::if_any(
+          dplyr::all_of(.cluster_column_name),
+          .fns = ~!is.na(.)
+        )) |>
+      dplyr::group_by(
+        dplyr::across(
+          dplyr::all_of(
+            .cluster_column_name))) |>
+      dplyr::summarise(dplyr::across(dplyr::all_of(.parameter), mean), .groups = "drop") |>
+      dplyr::arrange(dplyr::across(dplyr::all_of(.parameter))) |>
+      {\(x) if(.desc){
+        x[nrow(x):1, ]
+      }else{
+        x
+      }}() |>
+      dplyr::mutate({{.column_name}} := .analyte_id)
 
-  clust_order <- clust_order %>%
-    dplyr::select(!!rlang::sym(.cluster_column_name), !!.column_name)
+  clust_order <-
+    clust_order |>
+    dplyr::select(dplyr::one_of(.cluster_column_name, .column_name))
 
-  df %>%
-    dplyr::left_join(clust_order, by = .cluster_column_name) %>%
-    dplyr::select(-dplyr::one_of(.cluster_column_name))
+  df |>
+    dplyr::left_join(clust_order, by = .cluster_column_name) |>
+    dplyr::select(-dplyr::all_of(.cluster_column_name))
 }
 
 #' Identify bead populations
@@ -521,7 +544,21 @@ assign_analyte_id <- function(df,
 #' @keywords internal
 #'
 #' @examples
-#' x <- "a"
+#'
+#' library(beadplexr)
+#' data("lplex")
+#' df <- lplex[[1]]
+#'
+#' panel_info <- load_panel(.panel_name = "Human Growth Factor Panel (13-plex)")
+#' analytes <- panel_info$analytes
+#' call_args <-
+#'   list(.parameter = c("FSC-A", "SSC-A"),
+#'        .column_name = "Bead group",
+#'        .trim = 0.1,
+#'        .method = "clara")
+#'
+#' ident_bead_pop(.analytes = analytes, .call_args = call_args, df = df)
+#'
 ident_bead_pop <- function(.analytes, .column_name = NULL, .cluster = NULL, .call_args, df, .data = NULL){
   if(!is.null(.data)){
     raise_deprecated(old = ".data", new = "df", caller = "ident_bead_pop")
@@ -541,7 +578,12 @@ ident_bead_pop <- function(.analytes, .column_name = NULL, .cluster = NULL, .cal
   }
 
   if(!is.null(.cluster)){
-    df  <- df %>% dplyr::filter(!!rlang::sym(.column_name) == .cluster)
+    df  <- df |>
+      dplyr::filter(
+        dplyr::if_all(
+          dplyr::all_of(.column_name), ~ . == .cluster
+        )
+      )
   }
 
   .call_args[[".analyte_id"]] <- .analytes
@@ -560,25 +602,23 @@ ident_bead_pop <- function(.analytes, .column_name = NULL, .cluster = NULL, .cal
 #' @keywords internal
 #'
 #' @examples
-#' \dontrun{
 #' library(beadplexr)
-#' library(magrittr)
 #'
-#' list(.column_name = "XXX") %>% get_col_names_args
-#' list(A = list(.column_name = "XXX")) %>% get_col_names_args
-#' list(A = list(.column_name = "Inner"), .column_name = "Outer") %>% get_col_names_args
-#' list(A = "ccc") %>% get_col_names_args
-#' }
+#' list(.column_name = "XXX") |> beadplexr:::get_col_names_args()
+#' list(A = list(.column_name = "XXX")) |> beadplexr:::get_col_names_args()
+#' list(A = list(.column_name = "Inner"), .column_name = "Outer") |> beadplexr:::get_col_names_args()
+#' list(A = "ccc") |> beadplexr:::get_col_names_args()
+#'
 get_col_names_args <- function(.list){
   .elem_names <- names(.list)
 
   .col_name_elems <- grep(".column_name", .elem_names)
 
   if(length(.col_name_elems) > 0){
-    return(.list[.col_name_elems] %>%
-             purrr::flatten_chr())
+    return(.list[.col_name_elems] |>
+             purrr::list_c())
   }else{
-    .list <- .list %>% unlist(recursive = FALSE)
+    .list <- .list |> unlist(recursive = FALSE)
     if(inherits(.list, "list")){
       get_col_names_args(.list)
     }else{
