@@ -1,5 +1,3 @@
-context("Identify analytes")
-
 # Preparation -------------------------------------------------------------
 data("lplex")
 df <- lplex[[1]]
@@ -7,17 +5,17 @@ df <- lplex[[1]]
 
 # identify_analyte() ---------------------------------------------------
 test_that("Identify analyte works", {
-  expect_is(identify_analyte(df = df,
+  expect_s3_class(identify_analyte(df = df,
                                 .parameter = c("FSC-A", "SSC-A"),
                                 .analyte_id = c("A", "B"),
                                 .column_name = "ana lyte",
                                 .method = "clara", .trim = 0.02), "data.frame")
-  expect_is(identify_analyte(df = df,
+  expect_s3_class(identify_analyte(df = df,
                                 .parameter = c("FSC-A", "SSC-A"),
                                 .analyte_id = c("A", "B"),
                                 .column_name = "analyte",
                                 .method = "kmeans", .trim = 0.02), "data.frame")
-  expect_is(identify_analyte(df = df,
+  expect_s3_class(identify_analyte(df = df,
                                 .parameter = c("FSC-A", "SSC-A"),
                                 .analyte_id = c("A", "B"),
                                 .column_name = "analyte",
@@ -38,7 +36,7 @@ test_that("Identify analyte give warnings", {
 df <- bp_clara(df, .parameter = c("FSC-A", "SSC-A"), .column_name = "analyte", .k = 2)
 
 test_that("AnalyteIDs are assigned", {
-  expect_is(
+  expect_s3_class(
     assign_analyte_id(
       df = df,
       .parameter = c("FSC-A", "SSC-A"),
@@ -48,7 +46,7 @@ test_that("AnalyteIDs are assigned", {
     ),
     "data.frame"
   )
-  expect_is(
+  expect_s3_class(
     assign_analyte_id(
       df = df,
       .parameter = c("FSC-A", "SSC-A"),
@@ -90,7 +88,7 @@ test_that("AnalyteID column is overwritten", {
 
   df3 <- bp_clara(df2, .parameter = c("FSC-A", "SSC-A"), .column_name = "analyte", .k = 2)
 
-  expect_is(beadplexr:::assign_analyte_id(df = df3,
+  expect_s3_class(beadplexr:::assign_analyte_id(df = df3,
                                           .parameter = c("FSC-A", "SSC-A"),
                                           .analyte_id = c("A", "B"),
                                           .column_name = "pop name",
@@ -101,3 +99,31 @@ test_that("AnalyteID column is overwritten", {
                                                  .column_name = "pop name",
                                                  .cluster_column_name = "analyte"), df2)
 })
+
+
+# ident_bead_pop() --------------------------------------------------------
+
+test_that("Bead populations are identified", {
+  local_mocked_bindings(
+    identify_analyte = function(...) data.frame()
+  )
+
+  expect_s3_class(ident_bead_pop(.analytes = "", .call_args = list(), df = data.frame()), "data.frame")
+  expect_equal(nrow(ident_bead_pop(.analytes = "", .call_args = list(), df = data.frame())), 0)
+  expect_equal(
+    nrow(
+      ident_bead_pop(
+        .analytes = c("1"),
+        .call_args = list(),
+        .column_name = "cn",
+        .cluster = "cl",
+        df = data.frame(cn = "1", cl = "2"))), 0)
+
+  expect_error(
+    ident_bead_pop(.analytes = "", .call_args = list(), .column_name = "cn", df = data.frame())
+  )
+  expect_error(
+    ident_bead_pop(.analytes = "", .call_args = list(), .cluster = "cl", df = data.frame())
+  )
+
+})
