@@ -1,5 +1,3 @@
-context("Read and transform fcs file")
-
 test_that("Reading flow data is deprecated", {
  expect_warning(
     read_fcs(.file_name = "file_name")
@@ -13,8 +11,8 @@ test_that("Reading flow data is deprecated", {
 #
 # # Boundary events can be removed ------------------------------------------
 # test_that("Boundary events can be removed", {
-#   expect_is(remove_boundary_events(.flow_frame = .flow_frame, .channels = c("FSC-A", "SSC-A")), "flowFrame")
-#   expect_is(remove_boundary_events(.flow_frame = .flow_frame, .channels = c("FSC-A")), "flowFrame")
+#   expect_s3_class(remove_boundary_events(.flow_frame = .flow_frame, .channels = c("FSC-A", "SSC-A")), "flowFrame")
+#   expect_s3_class(remove_boundary_events(.flow_frame = .flow_frame, .channels = c("FSC-A")), "flowFrame")
 #   # Must have parameters
 #   # expect_error(remove_boundary_events(.flow_frame = .flow_frame, .channels = NULL))
 # })
@@ -22,9 +20,9 @@ test_that("Reading flow data is deprecated", {
 #
 # # Channels can be filtered ------------------------------------------------
 # test_that("Channels can be filtered", {
-#   expect_is(subset_channels(.flow_frame = .flow_frame, .filter = list("FSC-A" = c(1e5L, 8e5L))), "flowFrame")
-#   expect_is(subset_channels(.flow_frame = .flow_frame, .filter = list("FSC-A" = c(-Inf, 8e5L))), "flowFrame")
-#   expect_is(subset_channels(.flow_frame = .flow_frame, .filter = NULL), "flowFrame")
+#   expect_s3_class(subset_channels(.flow_frame = .flow_frame, .filter = list("FSC-A" = c(1e5L, 8e5L))), "flowFrame")
+#   expect_s3_class(subset_channels(.flow_frame = .flow_frame, .filter = list("FSC-A" = c(-Inf, 8e5L))), "flowFrame")
+#   expect_s3_class(subset_channels(.flow_frame = .flow_frame, .filter = NULL), "flowFrame")
 #   # Each list element must be a numeric vector of two
 #   expect_error(subset_channels(.flow_frame = .flow_frame, .filter = list("FSC-A" = c(8e5L))))
 #   expect_error(subset_channels(.flow_frame = .flow_frame, .filter = list("FSC-A" = c("A", "B"))))
@@ -32,7 +30,7 @@ test_that("Reading flow data is deprecated", {
 #
 # # Transformation can be applied -------------------------------------------
 # test_that("Transformation can be applied", {
-#   expect_is(transform_bead_channels(.flow_frame = .flow_frame, .bead_channels = c("FL6-H", "FL2-H")), "flowFrame")
+#   expect_s3_class(transform_bead_channels(.flow_frame = .flow_frame, .bead_channels = c("FL6-H", "FL2-H")), "flowFrame")
 #   # The channel must exist
 #   expect_error(transform_bead_channels(.flow_frame = .flow_frame, .bead_channels = c("FL6-H", "FL23-H")))
 #   # Beads are identified by intensity in one channel, and the relative level of the product is given by another channel
@@ -41,9 +39,9 @@ test_that("Reading flow data is deprecated", {
 #
 # # Expression set is exportet as data.frame --------------------------------
 # test_that("Expression set is exportet as data.frame", {
-#   expect_is(as_data_frame_flow_frame(.flow_frame = .flow_frame), "data.frame")
-#   expect_is(as_data_frame_flow_frame(.flow_frame = .flow_frame), "tbl")
-#   expect_is(as_data_frame_flow_frame(.flow_frame = .flow_frame, .channels = c("FSC-A", "SSC-A")), "tbl")
+#   expect_s3_class(as_data_frame_flow_frame(.flow_frame = .flow_frame), "data.frame")
+#   expect_s3_class(as_data_frame_flow_frame(.flow_frame = .flow_frame), "tbl")
+#   expect_s3_class(as_data_frame_flow_frame(.flow_frame = .flow_frame, .channels = c("FSC-A", "SSC-A")), "tbl")
 #   # Parameters must exist
 #   expect_error(as_data_frame_flow_frame(.flow_frame = .flow_frame, .channels = c(" ")))
 # })
@@ -57,11 +55,11 @@ test_that("Reading flow data is deprecated", {
 # colnames(comp_matrix) <- c("FL1-H", "FL2-H", "FL6-H", "FL1-A", "FL2-A", "FL6-A")
 #
 # test_that("Compensation can be applied", {
-#   expect_is(apply_compensation(.flow_frame = .flow_frame, .compensation = NULL), "flowFrame")
-#   expect_is(apply_compensation(.flow_frame = .flow_frame, .compensation = "guess"), "flowFrame")
-#   expect_is(apply_compensation(.flow_frame = .flow_frame, .compensation = "SPILL"), "flowFrame")
-#   expect_is(apply_compensation(.flow_frame = .flow_frame, .compensation = "spillover"), "flowFrame")
-#   expect_is(apply_compensation(.flow_frame = .flow_frame, .compensation = comp_matrix), "flowFrame")
+#   expect_s3_class(apply_compensation(.flow_frame = .flow_frame, .compensation = NULL), "flowFrame")
+#   expect_s3_class(apply_compensation(.flow_frame = .flow_frame, .compensation = "guess"), "flowFrame")
+#   expect_s3_class(apply_compensation(.flow_frame = .flow_frame, .compensation = "SPILL"), "flowFrame")
+#   expect_s3_class(apply_compensation(.flow_frame = .flow_frame, .compensation = "spillover"), "flowFrame")
+#   expect_s3_class(apply_compensation(.flow_frame = .flow_frame, .compensation = comp_matrix), "flowFrame")
 #
 #   # Warnings
 #   expect_warning(apply_compensation(.flow_frame = .flow_frame, .compensation = c("guess", "xxx")))
@@ -78,10 +76,10 @@ test_that("Reading flow data is deprecated", {
 #
 # # FACS files can be read and processed ------------------------------------
 # test_that("FACS files can be read and processed", {
-#   expect_is(read_fcs(.file_name = .file_name), "data.frame")
-#   expect_is(read_fcs(.file_name = .file_name, .filter = list("FSC-A" =  c(Inf, 5))), "data.frame")
-#   expect_is(read_fcs(.file_name = .file_name, .fsc_ssc = c("FSC-H", "SSC-H")), "data.frame")
-#   expect_is(read_fcs(.file_name = .file_name, .bead_channels = c("FSC-H", "SSC-H")), "data.frame")
+#   expect_s3_class(read_fcs(.file_name = .file_name), "data.frame")
+#   expect_s3_class(read_fcs(.file_name = .file_name, .filter = list("FSC-A" =  c(Inf, 5))), "data.frame")
+#   expect_s3_class(read_fcs(.file_name = .file_name, .fsc_ssc = c("FSC-H", "SSC-H")), "data.frame")
+#   expect_s3_class(read_fcs(.file_name = .file_name, .bead_channels = c("FSC-H", "SSC-H")), "data.frame")
 #   # Parameters must exist
 #   expect_error(read_fcs(.file_name = .file_name, .fsc_ssc = c("FSC-H", " ")))
 #   # Two forward side scatter channels
